==> haskell-js-jquery-3.7.1-96-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-js-jquery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 js-jquery
version:              3.7.1
visibility:           public
id:                   js-jquery-3.7.1-QAh7bbG5YJ8r5SU29zMxE
key:                  js-jquery-3.7.1-QAh7bbG5YJ8r5SU29zMxE
license:              MIT
copyright:            Neil Mitchell 2014-2025
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/js-jquery#readme
synopsis:             Obtain minified jQuery code
description:
    This package bundles the minified <http://jquery.com/ jQuery> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jQuery version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).

category:             Javascript
abi:                  52ad28702478913b62435c4acd9711a7
exposed:              True
exposed-modules:      Language.Javascript.JQuery
hidden-modules:       Paths_js_jquery
import-dirs:          /usr/lib/ghc-9.6.6/site-local/js-jquery-3.7.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/js-jquery-3.7.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/js-jquery-3.7.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-js-jquery
hs-libraries:         HSjs-jquery-3.7.1-QAh7bbG5YJ8r5SU29zMxE
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-js-jquery/html/js-jquery.haddock
haddock-html:         /usr/share/doc/haskell-js-jquery/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-js-jquery-3.7.1-98-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-js-jquery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 js-jquery
version:              3.7.1
visibility:           public
id:                   js-jquery-3.7.1-ADxF63TBJgx9QFKMq9ZWsw
key:                  js-jquery-3.7.1-ADxF63TBJgx9QFKMq9ZWsw
license:              MIT
copyright:            Neil Mitchell 2014-2025
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/js-jquery#readme
synopsis:             Obtain minified jQuery code
description:
    This package bundles the minified <http://jquery.com/ jQuery> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jQuery version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).

category:             Javascript
abi:                  8d9e258dbaf4a7acc8e664653c9cc48a
exposed:              True
exposed-modules:      Language.Javascript.JQuery
hidden-modules:       Paths_js_jquery
import-dirs:          /usr/lib/ghc-9.6.6/site-local/js-jquery-3.7.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/js-jquery-3.7.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/js-jquery-3.7.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-js-jquery
hs-libraries:         HSjs-jquery-3.7.1-ADxF63TBJgx9QFKMq9ZWsw
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-js-jquery/html/js-jquery.haddock
haddock-html:         /usr/share/doc/haskell-js-jquery/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
